<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX User Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Διαχείριση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Προσθήκη νέου χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Προσθήκη λογαριασμού χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Enter password for new user</source>
        <translation>Πληκτρολογήστε το κωδικό του νέου χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>password</source>
        <translation>κωδικός</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Reenter password for new user</source>
        <translation>Πληκτρολογήστε ξανά το κωδικό του νέου χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>confirm password</source>
        <translation>επιβεβαίωση κωδικού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Username of new user</source>
        <translation>Όνομα σύνδεσης νέου χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User login name:</source>
        <translation>Όνομα σύνδεσης χρήστη:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Enter username of new user</source>
        <translation>Πληκτρολογήστε το όνομα σύνδεσης του νέου χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <location filename="../mainwindow.ui" line="472"/>
        <source>username</source>
        <translation>όνομα χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.ui" line="258"/>
        <source>Password for new user</source>
        <translation>Κωδικός του νέου χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Confirm user password:</source>
        <translation>Επιβεβαίωση κωδικού χρήστη:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>User password:</source>
        <translation>Κωδικός χρήστη:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Grant this user administrative rights to the system (sudo)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Delete User Account</source>
        <translation>Διαγραφή λογαριασμού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Select user</source>
        <translation>Επιλογή χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <location filename="../mainwindow.ui" line="1436"/>
        <source>Select user to delete</source>
        <translation>Επιλογή χρήστη για διαγραφή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>User to delete:</source>
        <translation>Χρήστης για διαγραφή:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Διαγραφή και του αρχικού καταλόγου του χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Delete user home directory</source>
        <translation>Διαγραφή αρχικού καταλόγου του χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Rename User Account</source>
        <translation>Μετονομασία λογαριασμού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Select user to modify:</source>
        <translation>Επιλέξτε χρήστη για τροποποίηση:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>New user name:</source>
        <translation>Νέο όνομα χρήστη:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Change User Password</source>
        <translation>Αλλαγή κωδικού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>new password</source>
        <translation>νέος κωδικός</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Confirm new password:</source>
        <translation>Επιβεβαίωση νέου κωδικού:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>confirm new password</source>
        <translation>επιβεβαίωση νέου κωδικού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>New user password:</source>
        <translation>Νέος κωδικός:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Repair a user configuration</source>
        <translation>Επιδιόρθωση διαμόρφωσης ενός χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="1393"/>
        <source>Modify User Account</source>
        <translation>Τροποποίηση λογαριασμού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Select user to repair</source>
        <translation>Επιλογή χρήστη για αλλαγή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>User to change:</source>
        <translation>Χρήστης για αλλαγή:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <source>Restore Defaults</source>
        <translation>Επαναφορά προεπιλογών</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Επαναφορά του προγράμματος περιήγησης στις προεπιλογές του ΜΧ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Ρυθμίσεις του Mozilla (Firefox ή Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Επαναφορά των μελών της ομάδας στις προεπιλογές του MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Group memberships</source>
        <translation>Μέλη ομάδας</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Change Autologin Settings</source>
        <translation>Ρυθμίσεις αυτόματης σύνδεσης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>Log in automatically</source>
        <translation>Αυτόματη σύνδεση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>Require password to log in</source>
        <translation>Απαίτηση κωδικού για τη σύνδεση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Copy/Sync</source>
        <translation>Αντιγραφή/Συγχρονισμός</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Copy Between Desktops</source>
        <translation>Αντιγραφή μεταξύ υπολογιστών</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <location filename="../mainwindow.ui" line="922"/>
        <source>Select desktop to copy from</source>
        <translation>Επιλογή υπολογιστή από τον οποίον θα αντιγράψετε</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>Select to only copy files</source>
        <translation>Επιλογή μόνο αντιγραφής των αρχείων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <source>Copy only</source>
        <translation>Μόνο αντιγραφή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select desktop to copy to</source>
        <translation>Επιλογή υπολογιστή στον οποίον θα αντιγράψετε</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="909"/>
        <source>Copy to:</source>
        <translation>Αντιγραφή σε:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="931"/>
        <source>Copy from:</source>
        <translation>Αντιγραφή από:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="944"/>
        <source>Select to copy and then delete differences</source>
        <translation>Επιλογή αντιγραφής και στη συνέχεια διαγραφή διαφορών</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Sync</source>
        <translation>Συγχρονισμός</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="993"/>
        <source>Select to copy/sync Shared</source>
        <translation>Επιλογή αντιγραφής/συγχρονισμού κοινόχρηστου φακέλου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="996"/>
        <source>Shared folder</source>
        <translation>Κοινόχρηστος φάκελος</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1009"/>
        <source>Select to copy/sync entire home</source>
        <translation>Επιλογή αντιγραφής/συγχρονισμού όλου του αρχικού καταλόγου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1012"/>
        <source>Entire home</source>
        <translation>Όλος ο αρχικός κατάλογος</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1028"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Επιλογή αντιγραφής/συγχρονισμού των ρυθμίσεων του προγράμματος περιήγησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1031"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Ρυθμίσεις του Mozilla (Firefox ή Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>Select to copy/sync Documents</source>
        <translation>Επιλογή αντιγραφής/συγχρονισμού του καταλόγου Έγγραφα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1047"/>
        <source>Documents folder</source>
        <translation>Κατάλογος Εγγράφων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1054"/>
        <source>What to copy/sync:</source>
        <translation>Τι να αντιγράψετε/συγχρονίσετε:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1070"/>
        <source>Progress</source>
        <translation>Πρόοδος</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1100"/>
        <location filename="../mainwindow.ui" line="1116"/>
        <source>Status of the changes</source>
        <translation>Κατάσταση αλλαγών</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1119"/>
        <source>Status:</source>
        <translation>Κατάσταση:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Progress of the changes</source>
        <translation>Πρόοδος αλλαγών</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1172"/>
        <source>Add/Remove Groups</source>
        <translation>Προσθήκη/Αφαίρεση ομάδων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <source>Add Group</source>
        <translation>Προσθήκη ομάδας</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1211"/>
        <source>Enter name of new group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>groupname</source>
        <translation>όνομα ομάδας</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Create a user-level group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <source>Group name:</source>
        <translation>Όνομα ομάδας:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1281"/>
        <source>Delete Group</source>
        <translation>Διαγραφή ομάδας</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1350"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Select group to delete:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1366"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1381"/>
        <source>Group Membership</source>
        <translation>Μέλος ομάδας</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Ομάδες που ανήκει ο χρήστης (αλλάξτε τις ομάδες επιλέγοντας ή όχι τα κατάλληλα κουτάκια):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1478"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Cancel any changes then quit</source>
        <translation>Ακύρωση αλλαγών και κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1586"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1593"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Display help </source>
        <translation>Εμφάνιση βοήθειας </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1637"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Apply any changes</source>
        <translation>Εφαρμογή αλλαγών</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1654"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>About this application</source>
        <translation>Περί της εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>About...</source>
        <translation>Περί...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1678"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <location filename="../mainwindow.cpp" line="148"/>
        <location filename="../mainwindow.cpp" line="156"/>
        <location filename="../mainwindow.cpp" line="174"/>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="665"/>
        <location filename="../mainwindow.cpp" line="689"/>
        <location filename="../mainwindow.cpp" line="716"/>
        <location filename="../mainwindow.cpp" line="864"/>
        <location filename="../mainwindow.cpp" line="965"/>
        <location filename="../mainwindow.cpp" line="971"/>
        <location filename="../mainwindow.cpp" line="976"/>
        <location filename="../mainwindow.cpp" line="979"/>
        <location filename="../mainwindow.cpp" line="981"/>
        <source>none</source>
        <translation>κανένα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="133"/>
        <location filename="../mainwindow.cpp" line="652"/>
        <location filename="../mainwindow.cpp" line="870"/>
        <location filename="../mainwindow.cpp" line="878"/>
        <source>browse...</source>
        <translation>περιήγηση...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Η διαμόρφωση του χρήστη θα επιδιορθωθεί. Παρακαλώ κλείστε τώρα όλες τις άλλες εφαρμογές. Όταν τελειώσει, μπορείτε να αποσυνδεθείτε ή να επανεκκινήσετε. Είστε βέβαιοι ότι θέλετε να επιδιορθώσετε τώρα;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="221"/>
        <source>User group membership was restored.</source>
        <translation>Η ομάδα μελών του χρήστη αποκαταστάθηκε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Mozilla settings were reset.</source>
        <translation>Επαναφέρονται οι ρυθμίσεις του Mozilla.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Autologin options</source>
        <translation>Επιλογές αυτόματης εκκίνησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Η αυτόματη εκκίνηση για το λογαριασμό &apos;%1&apos; έχει απενεργοποιηθεί.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Η αυτόματη εκκίνηση για το λογαριασμό &apos;%1&apos; έχει ενεργοποιηθεί.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Πρέπει να καθορίσετε προορισμό για το &apos;αντίγραφο&apos;. Δεν μπορείτε να αντιγράψετε στον υπολογιστή που είστε συνδεδεμένοι.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Πριν την αντιγραφή, κλείστε όλες τις άλλες εφαρμογές. Να είστε βέβαιοι ότι το αντίγραφο προορισμού, είναι αρκετά μεγάλο ώστε να περιέχει όλα τα αρχεία που θέλετε να αντιγράψετε. Η αντιγραφή μεταξύ των υπολογιστών μπορεί να αντικαταστήσει ή να διαγράψει αρχεία και προτιμήσεις στον υπολογιστή προορισμού. Είστε σίγουροι ότι θέλετε να συνεχίσετε;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Synchronizing desktop...</source>
        <translation>Συγχρονισμός υπολογιστών...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Copying desktop...</source>
        <translation>Αντιγραφή υπολογιστών...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Το όνομα χρήστη πρέπει να έχει μήκος τουλάχιστον 2 χαρακτήρων. Παρακαλώ επιλέξτε μεγαλύτερο όνομα πριν συνεχίσετε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Το όνομα χρήστη δεν μπορεί να περιέχει ειδικούς χαρακτήρες ή κενά.
Παρακαλούμε επιλέξτε ένα άλλο όνομα πριν προχωρήσετε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Λυπούμαστε, αυτό το όνομα χρησιμοποιείται. Παρακαλώ πληκτρολογήστε διαφορετικό όνομα.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Οι κωδικοί δεν ταιριάζουν μεταξύ τους. Παρακαλώ προσπαθήστε ξανά.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Ο κωδικός πρέπει να έχει τουλάχιστον μήκος 2 χαρακτήρων. Παρακαλώ πληκτρολογήστε μεγαλύτερο κωδικό πριν συνεχίσετε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>The user was added ok.</source>
        <translation>Προστέθηκε νέος χρήστης.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Failed to add the user.</source>
        <translation>Απέτυχε η προσθήκη χρήστη.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Password successfully changed.</source>
        <translation>Ο κωδικός άλλαξε με επιτυχία.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Failed to change password.</source>
        <translation>Απέτυχε η αλλαγή κωδικού.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Η ενέργεια αυτή δεν θα μπορεί να αναιρεθεί. Είστε βέβαιοι ότι θέλετε να διαγράψετε το χρήστη %1;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>The user has been deleted.</source>
        <translation>Ο χρήστης διαγράφτηκε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Failed to delete the user.</source>
        <translation>Απέτυχε η διαγραφή του χρήστη.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Το όνομα της ομάδας πρέπει να έχει μήκος τουλάχιστον 2 χαρακτήρων. Παρακαλώ επιλέξτε μεγαλύτερο όνομα πριν συνεχίσετε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Το όνομα της ομάδας πρέπει να είναι με πεζά και 
δεν μπορεί να περιέχει ειδικούς χαρακτήρες ή κενά.
Παρακαλώ επιλέξτε άλλο όνομα πριν προχωρήσετε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Λυπούμαστε, το όνομα της ομάδας υπάρχει ήδη. Παρακαλώ πληκτρολογήστε διαφορετικό όνομα.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>The system group was added ok.</source>
        <translation>Προστέθηκε η ομάδα στο σύστημα.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>Failed to add the system group.</source>
        <translation>Απέτυχε η προσθήκη ομάδας στο συστήμα.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="469"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Αυτή η ενέργεια δεν θα μπορεί να αναιρεθεί. Είστε βέβαιοι ότι θέλετε να διαγράψετε την ομάδα %1;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Failed to delete the group.</source>
        <translation>Απέτυχε η διαγραφή της ομάδας.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Group: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>The group has been deleted.</source>
        <translation>Η ομάδα έχει διαγραφεί.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>The groups have been deleted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>The changes have been applied.</source>
        <translation>Οι αλλαγές έχουν εφαρμοστεί.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Failed to apply group changes</source>
        <translation>Απέτυχε η εφαρμογή αλλαγών στην ομάδα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>The selected user name is currently in use.</source>
        <translation>Το όνομα χρήστη που επιλέξατε χρησιμοποιείται ήδη.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Για να μετονομάσετε αυτόν τον χρήστη, αποσυνδεθείτε και συνδεθείτε ξανά χρησιμοποιώντας άλλο λογαριασμό χρήστη.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Το όνομα χρήστη πρέπει να είναι με πεζά και δεν
μπορεί να περιέχει ειδικούς χαρακτήρες ή κενά.
Παρακαλώ επιλέξτε άλλο όνομα πριν προχωρήσετε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Λυπούμαστε, αυτό το όνομα υπάρχει ήδη στο σύστημά σας. Παρακαλώ πληκτρολογήστε διαφορετικό όνομα.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Απέτυχε η μετονομασία του χρήστη. Βεβαιωθείτε ότι ο χρήστης δεν είναι συνδεδεμένος, ίσως και να χρειάζεται επανεκκίνηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>The user was renamed.</source>
        <translation>Ο χρήστης μετονομάστηκε.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <location filename="../mainwindow.cpp" line="606"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Ο συγχρονισμός υπολογιστών...επιτυχής</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <location filename="../mainwindow.cpp" line="608"/>
        <source>Copying desktop...ok</source>
        <translation>Η αντιγραφή υπολογιστών...επιτυχής</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Ο συγχρονισμός υπολογιστών   απέτυχε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="613"/>
        <source>Copying desktop...failed</source>
        <translation>Η αντιγραφή υπολογιστών...απέτυχε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Confirmation</source>
        <translation>Επιβεβαίωση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="631"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation>Η διαδικασία δεν ολοκληρώθηκε. Είστε βέβαιοι ότι θέλετε να τερματίσετε την εφαρμογή;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="836"/>
        <source>About %1</source>
        <translation>Περί του %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>Version: </source>
        <translation>Έκδοση: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="838"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Απλός διαχειριστής χρήστη του MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>%1 License</source>
        <translation>Άδεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="855"/>
        <source>%1 Help</source>
        <translation>Βοήθεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="871"/>
        <source>Select folder to copy to</source>
        <translation>Επιλογή καταλόγου στον οποίον θα αντιγράψετε</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Φαίνεται ότι έχετε συνδεθεί ως root, αποσυνδεθείτε και συνδεθείτε ως κανονικός χρήστης για να χρησιμοποιήσετε αυτό το πρόγραμμα.</translation>
    </message>
</context>
</TS>
